pub struct Transaction {
pub command: Option<String>,
pub started: DateTime<FixedOffset>,
pub completed: Option<DateTime<FixedOffset>>,
pub operations: Vec<LogEntry>,
}Expand description
A single pacman commit: the operations applied between a transaction started and transaction completed marker.
Fields
command: Option<String>started: DateTime<FixedOffset>completed: Option<DateTime<FixedOffset>>operations: Vec<LogEntry>Trait Implementations
Sourceimpl Clone for Transaction
impl Clone for Transaction
Sourcefn clone(&self) -> Transaction
fn clone(&self) -> Transaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Transaction
impl Debug for Transaction
impl Eq for Transaction
Sourceimpl PartialEq for Transaction
impl PartialEq for Transaction
Sourcefn eq(&self, other: &Transaction) -> bool
fn eq(&self, other: &Transaction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Transaction