parse_entry

Function parse_entry 

pub fn parse_entry(line: &str) -> Option<Entry>
Parse any pacman log line into an Entry, not just package operations.

Returns None if the line is not a well-formed [timestamp] [caller] message.